==> isis-fish-4.0.0.0-sources.jar: fr/ifremer/isisfish/equation/ImmigrationEquation.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: ImmigrationEquation.java 3428 2011-06-22 14:47:43Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.equation;

import org.nuiton.math.matrix.MatrixND;

import fr.ifremer.isisfish.entities.Population;
import fr.ifremer.isisfish.entities.PopulationGroup;
import fr.ifremer.isisfish.entities.Zone;
import fr.ifremer.isisfish.simulator.SimulationContext;
import fr.ifremer.isisfish.util.Args;

/**
 * Immigration equation.
 *
 * Created: 23 août 2006 12:06:32
 *
 * @author poussin
 * @version $Revision: 3428 $
 *
 * Last update: $Date: 2011-06-22 16:47:43 +0200 (mer., 22 juin 2011) $
 * by : $Author: chatellier $
 */
public interface ImmigrationEquation {
    
    /**
     * Compute immigration equation.
     * 
     * @param context simulation context
     * @param N effectif de la population
     * @param pop la population pour lequel on souhaite le nombre d'immigration
     * @param group le group pour lequel on souhaite le nombre d'immigration
     * @param arrivalZone la zone d'arrivé de l'immigration
     * @return le nombre d'individu a immigrer dans la zone
     * d'arrivé pour le groupe passé en argument
     * @throws Exception 
     */
   @Args({"context", "N", "pop", "group", "arrivalZone"})
    public double compute(SimulationContext context,
            MatrixND N, Population pop, PopulationGroup group,
            Zone arrivalZone) throws Exception;

}

==> isis-fish-4.1.1.1-sources.jar: fr/ifremer/isisfish/equation/ImmigrationEquation.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: ImmigrationEquation.java 3671 2012-04-03 13:31:36Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2006 - 2011 Ifremer, Code Lutin, Cédric Pineau, Benjamin Poussin, Chatellier Eric
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.equation;

import org.nuiton.math.matrix.MatrixND;

import fr.ifremer.isisfish.entities.Population;
import fr.ifremer.isisfish.entities.PopulationGroup;
import fr.ifremer.isisfish.entities.Zone;
import fr.ifremer.isisfish.simulator.SimulationContext;
import fr.ifremer.isisfish.util.Args;

/**
 * Immigration equation.
 *
 * Created: 23 août 2006 12:06:32
 *
 * @author poussin
 * @version $Revision: 3671 $
 *
 * Last update: $Date: 2012-04-03 15:31:36 +0200 (Tue, 03 Apr 2012) $
 * by : $Author: echatellier $
 */
public interface ImmigrationEquation {
    
    /**
     * Compute immigration equation.
     * 
     * @param context simulation context
     * @param N effectif de la population
     * @param pop la population pour lequel on souhaite le nombre d'immigration
     * @param group le group pour lequel on souhaite le nombre d'immigration
     * @param arrivalZone la zone d'arrivé de l'immigration
     * @return le nombre d'individu a immigrer dans la zone
     * d'arrivé pour le groupe passé en argument
     * @throws Exception 
     */
    @Args({"context", "N", "pop", "group", "arrivalZone"})
    public double compute(SimulationContext context,
            MatrixND N, Population pop, PopulationGroup group,
            Zone arrivalZone) throws Exception;

}
